@@ -7,6 +7,7 @@ use crosstermion::{
     ansi_term::{ANSIString, ANSIStrings, Color, Style},
     color,
 };
+use std::sync::atomic::Ordering;
 use std::{collections::VecDeque, io, ops::RangeInclusive};
 use unicode_width::UnicodeWidthStr;
 
@@ -237,7 +238,7 @@ fn draw_progress_bar<'a>(
             const CHARS: [char; 6] = ['=', '=', '=', ' ', ' ', ' '];
             buf.push(
                 styled_brush.paint(
-                    (p.step as usize..std::usize::MAX)
+                    (p.step.load(Ordering::SeqCst) as usize..std::usize::MAX)
                         .take(blocks_available as usize)
                         .map(|idx| CHARS[idx % CHARS.len()])
                         .rev()
@@ -290,15 +291,15 @@ fn format_progress<'a>(
             let values_brush = brush.style(Style::new().bold().dimmed());
             match progress.unit.as_ref() {
                 Some(unit) => {
-                    let mut display = unit.display(progress.step, progress.done_at, throughput);
+                    let mut display = unit.display(progress.step.load(Ordering::SeqCst), progress.done_at, throughput);
                     buf.push(values_brush.paint(display.values().to_string()));
                     buf.push(" ".into());
                     buf.push(display.unit().to_string().into());
                 }
                 None => {
                     buf.push(values_brush.paint(match progress.done_at {
-                        Some(done_at) => format!("{}/{}", progress.step, done_at),
-                        None => format!("{}", progress.step),
+                        Some(done_at) => format!("{}/{}", progress.step.load(Ordering::SeqCst), done_at),
+                        None => format!("{}", progress.step.load(Ordering::SeqCst)),
                     }));
                 }
             }
